@@ -5,6 +5,8 @@ from .projects import Projects
 from .cost_centers import CostCenters
 from .expense_custom_fields import ExpenseCustomFields
 from .corporate_cards  import CorporateCards
+from .reimbursements import Reimbursements
+from .tax_groups import TaxGroups
 
 __all__ = [
     'Expenses',
@@ -13,5 +15,7 @@ __all__ = [
     'Projects',
     'CostCenters',
     'ExpenseCustomFields',
-    'CorporateCards'
+    'CorporateCards',
+    'Reimbursements',
+    'TaxGroups'
 ]
