@@ -4,7 +4,8 @@ import os
 from fyle.platform import Platform
 
 from apps.workspaces.models import FyleCredential
-from .apis import Expenses, Employees, Categories, Projects, CostCenters, ExpenseCustomFields, CorporateCards
+from .apis import Expenses, Employees, Categories, Projects, CostCenters, ExpenseCustomFields, CorporateCards, \
+    Reimbursements, TaxGroups
 
 logger = logging.getLogger(__name__)
 logger.level = logging.INFO
@@ -37,11 +38,12 @@ class PlatformConnector:
         self.cost_centers = CostCenters()
         self.expense_custom_fields = ExpenseCustomFields()
         self.corporate_cards = CorporateCards()
+        self.reimbursements = Reimbursements()
+        self.tax_groups = TaxGroups()
 
         self.set_connection()
         self.set_workspace_id()
 
-
     def set_connection(self):
         """Set connection with Fyle Platform APIs."""
         self.expenses.set_connection(self.connection.v1beta.admin.expenses)
@@ -51,7 +53,8 @@ class PlatformConnector:
         self.cost_centers.set_connection(self.connection.v1beta.admin.cost_centers)
         self.expense_custom_fields.set_connection(self.connection.v1beta.admin.expense_fields)
         self.corporate_cards.set_connection(self.connection.v1beta.admin.corporate_cards)
-
+        self.reimbursements.set_connection(self.connection.v1beta.admin.reimbursements)
+        self.tax_groups.set_connection(self.connection.v1beta.admin.tax_groups)
 
     def set_workspace_id(self):
         """Set workspace ID for Fyle Platform APIs."""
@@ -62,12 +65,16 @@ class PlatformConnector:
         self.cost_centers.set_workspace_id(self.workspace_id)
         self.expense_custom_fields.set_workspace_id(self.workspace_id)
         self.corporate_cards.set_workspace_id(self.workspace_id)
+        self.reimbursements.set_workspace_id(self.workspace_id)
+        self.tax_groups.set_workspace_id(self.workspace_id)
 
-
-    def import_fyle_dimensions(self):
+    def import_fyle_dimensions(self, import_taxes: bool = False):
         """Import Fyle Platform dimension."""
         apis = ['employees', 'categories', 'projects', 'cost_centers', 'expense_custom_fields', 'corporate_cards']
 
+        if import_taxes:
+            apis.append('tax_groups')
+
         for api in apis:
             dimension = getattr(self, api)
             try:
